virtio_blk: revert QUEUE_FLAG_VIRT addition
Subsystems (4)
PATCH 1/1 virtio_blk: revert QUEUE_FLAG_VIRT addition
It seems like the addition of QUEUE_FLAG_VIRT caueses major performance regressions for Fedora users:
https://bugzilla.redhat.com/show_bug.cgi?id=509383 https://bugzilla.redhat.com/show_bug.cgi?id=505695
while I can't reproduce those extreme regressions myself I think the flag is wrong.
Rationale:
QUEUE_FLAG_VIRT expands to QUEUE_FLAG_NONROT which casus the queue unplugged immediately. This is not a good behaviour for at least qemu and kvm where we do have significant overhead for every I/O operations. Even with all the latested speeups (native AIO, MSI support, zero copy) we can only get native speed for up to 128kb I/O requests we already are down to 66% of native performance for 4kb requests even on my laptop running the Intel X25-M SSD for which the QUEUE_FLAG_NONROT was designed.
If we ever get virtio-blk overhead low enough that this flag makes sense it should only be set based on a feature flag set by the host.
drivers/block/virtio_blk.c +0 -1
@@ -314,7 +314,6 @@ static int __devinit virtblk_probe(struc } vblk->disk->queue->queuedata = vblk; -queue_flag_set_unlocked (QUEUE_FLAG_VIRT , vblk->disk->queue);if (index <26 ) {sprintf (vblk->disk->disk_name,"vd%c" ,'a' + index %26 );
Quoted 11 lines · Christoph Hellwig
It seems like the addition of
QUEUE_FLAG_VIRTcaueses major performance regressions for Fedora users:https://bugzilla.redhat.com/show_bug.cgi?id=509383 https://bugzilla.redhat.com/show_bug.cgi?id=505695while I can't reproduce those extreme regressions myself I think the flag is wrong.
Rationale:
Quoted 10 lines
QUEUE_FLAG_VIRTexpands toQUEUE_FLAG_NONROTwhich casus the queue unplugged immediately. This is not a good behaviour for at least qemu and kvm where we do have significant overhead for every I/O operations. Even with all the latested speeups (native AIO, MSI support, zero copy) we can only get native speed for up to 128kb I/O requests we already are down to 66% of native performance for 4kb requests even on my laptop running the Intel X25-M SSD for which theQUEUE_FLAG_NONROTwas designed.
If we ever get virtio-blk overhead low enough that this flag makes sense it should only be set based on a feature flag set by the host.
I agree with that rationale.